ndarray(data)
#############

.. doxygenfunction:: librapid::Array::Array(const std::vector<V> &values)
.. doxygenfunction:: librapid::Array::fromData(V scalar)
.. doxygenfunction:: librapid::Array::fromData(const std::vector<V> &data)
